import matplotlib.pyplot as plt

def line_chart(data: dict, title: str) -> None:
    plt.rcParams['font.sans-serif'] = ['SimHei']
    x = list(data['datas'].keys())
    y = list(data['datas'].values())
    plt.plot(x,y)
    plt.xlabel(data['unit'])
    plt.ylabel(data["count_unit"])
    plt.title(title)
    plt.show()




# -*- coding:utf-8 -*-
"""
Author: Wdataorg
Date: .11.12
Project Name: Wdata
"""

import math

def similarity(xy1: tuple, xy2: tuple) -> float:
    """
    This function can use the cosine similarity formula to calculate the similarity of the two coordinates and return
    the similarity value

    :param xy1: tuple
    :param xy2: tuple
    :return: float
    """
    result = (xy1[0] * xy2[0] + xy1[1] * xy2[1]) / ((math.sqrt(xy1[0] ** 2 + xy1[1] ** 2)) * (math.sqrt(xy2[0] ** 2 + xy2[1] ** 2)))
    return result

def distance(xy1: tuple, xy2: tuple) -> float:
    """
    This function can use Euclid distance formula to calculate the distance of 2 coordinates and return
     the distance value

    :param xy1: tuple
    :param xy2: tuple
    :return: float
    """
    result = math.sqrt((xy1[0] - xy2[0])**2 + (xy1[1]-xy2[1])**2)
    return result


# -*- coding:utf-8 -*-
"""
Author: Wdataorg
Date: 2022.06.17
Project Name: Wdata
"""

class JsonError(Exception):
    """
    The error is triggered when:
        1. The dataset entered by the user does not exist
    """
    def __init__(self, message):
        super().__init__(message)

class FileTypeError(Exception):
    """
    The error is triggered when:
        1. The file format entered by the user does not exist
    """
    def __init__(self):
        def __init__(self, message):
            super().__init__(mesage)


# -*- coding:utf-8 -*-
"""
Author: Wdataorg
Date: 2022.06.17
Project Name: Wdata
"""

from ..data_py import data


def read_dict(fname: str) -> dict:
    return data[fname]['datas']

def read_dict_draw(fname:str) -> list:
    file = data[fname]
    return [file, file['Type']]
